@@ -1,7 +1,7 @@
-from __future__ import unicode_literals
-
 import importlib
+import warnings
 
+from asgiref.compatibility import guarantee_single_callable
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.urls.exceptions import Resolver404
@@ -9,7 +9,6 @@ from django.urls.resolvers import URLResolver
 
 from channels.http import AsgiHandler
 
-
 """
 All Routing instances inside this file are also valid ASGI applications - with
 new Channels routing, whatever you end up with as the top level object is just
@@ -38,6 +37,20 @@ def get_default_application():
     return value
 
 
+DEPRECATION_MSG = """
+Using ProtocolTypeRouter without an explicit "http" key is deprecated.
+Given that you have not passed the "http" you likely should use Django's
+get_asgi_application():
+
+    from django.core.asgi import get_asgi_application
+
+    application = ProtocolTypeRouter(
+        "http": get_asgi_application()
+        # Other protocols here.
+    )
+"""
+
+
 class ProtocolTypeRouter:
     """
     Takes a mapping of protocol type names to other Application instances,
@@ -47,11 +60,15 @@ class ProtocolTypeRouter:
     def __init__(self, application_mapping):
         self.application_mapping = application_mapping
         if "http" not in self.application_mapping:
-            self.application_mapping["http"] = AsgiHandler
+            warnings.warn(DEPRECATION_MSG, DeprecationWarning, stacklevel=2)
+            self.application_mapping["http"] = AsgiHandler()
 
-    def __call__(self, scope):
+    async def __call__(self, scope, receive, send):
         if scope["type"] in self.application_mapping:
-            return self.application_mapping[scope["type"]](scope)
+            application = guarantee_single_callable(
+                self.application_mapping[scope["type"]]
+            )
+            return await application(scope, receive, send)
         else:
             raise ValueError(
                 "No application configured for scope type %r" % scope["type"]
@@ -101,22 +118,20 @@ class URLRouter:
 
     def __init__(self, routes):
         self.routes = routes
-        # Django 2 introduced path(); older routes have no "pattern" attribute
-        if self.routes and hasattr(self.routes[0], "pattern"):
-            for route in self.routes:
-                # The inner ASGI app wants to do additional routing, route
-                # must not be an endpoint
-                if getattr(route.callback, "_path_routing", False) is True:
-                    route.pattern._is_endpoint = False
 
         for route in self.routes:
+            # The inner ASGI app wants to do additional routing, route
+            # must not be an endpoint
+            if getattr(route.callback, "_path_routing", False) is True:
+                route.pattern._is_endpoint = False
+
             if not route.callback and isinstance(route, URLResolver):
                 raise ImproperlyConfigured(
                     "%s: include() is not supported in URLRouter. Use nested"
                     " URLRouter instances instead." % (route,)
                 )
 
-    def __call__(self, scope):
+    async def __call__(self, scope, receive, send):
         # Get the path
         path = scope.get("path_remaining", scope.get("path", None))
         if path is None:
@@ -131,7 +146,8 @@ class URLRouter:
                     new_path, args, kwargs = match
                     # Add args or kwargs into the scope
                     outer = scope.get("url_route", {})
-                    return route.callback(
+                    application = guarantee_single_callable(route.callback)
+                    return await application(
                         dict(
                             scope,
                             path_remaining=new_path,
@@ -139,7 +155,9 @@ class URLRouter:
                                 "args": outer.get("args", ()) + args,
                                 "kwargs": {**outer.get("kwargs", {}), **kwargs},
                             },
-                        )
+                        ),
+                        receive,
+                        send,
                     )
             except Resolver404:
                 pass
@@ -159,14 +177,17 @@ class ChannelNameRouter:
     def __init__(self, application_mapping):
         self.application_mapping = application_mapping
 
-    def __call__(self, scope):
+    async def __call__(self, scope, receive, send):
         if "channel" not in scope:
             raise ValueError(
                 "ChannelNameRouter got a scope without a 'channel' key. "
                 + "Did you make sure it's only being used for 'channel' type messages?"
             )
         if scope["channel"] in self.application_mapping:
-            return self.application_mapping[scope["channel"]](scope)
+            application = guarantee_single_callable(
+                self.application_mapping[scope["channel"]]
+            )
+            return await application(scope, receive, send)
         else:
             raise ValueError(
                 "No application configured for channel name %r" % scope["channel"]
