@@ -380,23 +380,22 @@ async def test_handler_concurrent_requests():
     await comm_2.receive_output(1)  # response body
 
 
+class SimpleHttpApp(AsyncConsumer):
+    """
+    Barebones HTTP ASGI app for testing.
+    """
+
+    async def http_request(self, event):
+        await database_sync_to_async(self.scope["session"].save)()
+        assert self.scope["path"] == "/test/"
+        assert self.scope["method"] == "GET"
+        await self.send({"type": "http.response.start", "status": 200, "headers": []})
+        await self.send({"type": "http.response.body", "body": b"test response"})
+
+
 @pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
 async def test_sessions():
-    class SimpleHttpApp(AsyncConsumer):
-        """
-        Barebones HTTP ASGI app for testing.
-        """
-
-        async def http_request(self, event):
-            await database_sync_to_async(self.scope["session"].save)()
-            assert self.scope["path"] == "/test/"
-            assert self.scope["method"] == "GET"
-            await self.send(
-                {"type": "http.response.start", "status": 200, "headers": []}
-            )
-            await self.send({"type": "http.response.body", "body": b"test response"})
-
     app = SimpleHttpApp()
 
     communicator = HttpCommunicator(SessionMiddlewareStack(app), "GET", "/test/")
@@ -419,6 +418,41 @@ async def test_sessions():
 
     assert re.compile(r"Path").search(value) is not None
 
+    samesite = re.compile(r"SameSite=(\w+)").search(value)
+    assert samesite is not None
+    assert samesite.group(1) == "Lax"
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.asyncio
+async def test_session_samesite(samesite, settings):
+    app = SimpleHttpApp()
+
+    communicator = HttpCommunicator(SessionMiddlewareStack(app), "GET", "/test/")
+    response = await communicator.get_response()
+    headers = response.get("headers", [])
+
+    assert len(headers) == 1
+    name, value = headers[0]
+
+    assert name == b"Set-Cookie"
+    value = value.decode("utf-8")
+
+    samesite = re.compile(r"SameSite=(\w+)").search(value)
+    assert samesite is not None
+    assert samesite.group(1) == settings.SESSION_COOKIE_SAMESITE
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.asyncio
+async def test_session_samesite_invalid(samesite_invalid):
+    app = SimpleHttpApp()
+
+    communicator = HttpCommunicator(SessionMiddlewareStack(app), "GET", "/test/")
+
+    with pytest.raises(AssertionError):
+        await communicator.get_response()
+
 
 @pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
